import { useMutation, useQuery } from "@apollo/client";
import {
  IconButton,
  Paper,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
} from "@material-ui/core";
import { FC } from "react";
import { Tag } from "../generated/graphql";
import EditIcon from "@material-ui/icons/Edit";
import { useRouter } from "@curi/react-dom";
import { Delete } from "@material-ui/icons";
import { REMOVE_TAG, TAGS } from "./tags.constants";

export const TagsIndex: FC = () => {
  const { data } = useQuery<{
    tags: Tag[];
  }>(TAGS, {});

  const [removeArticle] = useMutation<any, { id: string }>(REMOVE_TAG);

  const router = useRouter();

  return (
    <section>
      <TableContainer component={Paper}>
        <Table aria-label="articles table">
          <TableHead>
            <TableRow>
              <TableCell>Tag Name</TableCell>
              <TableCell>Views</TableCell>
              <TableCell>Articles</TableCell>
              <TableCell>Actions</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {data?.tags.map((tag) => (
              <TableRow key={tag.id}>
                <TableCell component="th" scope="row">
                  {tag.name}
                </TableCell>
                <TableCell align="right"> -- </TableCell>
                <TableCell align="right"> -- </TableCell>
                <TableCell>
                  <IconButton
                    aria-label="edit"
                    onClick={() =>
                      router.navigate({
                        url: router.url({
                          name: "modify-tag",
                          params: tag,
                        }),
                      })
                    }
                  >
                    <EditIcon />
                  </IconButton>
                  <IconButton
                    aria-label="delete"
                    onClick={() =>
                      removeArticle({
                        variables: tag,
                      })
                    }
                  >
                    <Delete />
                  </IconButton>
                </TableCell>
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </section>
  );
};
